@@ -35,8 +35,8 @@ class LayerDelegate : public QAbstractItemDelegate
 
   public:
     LayerDelegate(QObject* parent = 0);
-    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
-    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    void paint(QPainter* painter, QStyleOptionViewItem const& option, QModelIndex const& index) const;
+    QSize sizeHint(QStyleOptionViewItem const& option, QModelIndex const& index) const;
 };
 
 #endif // LAYER_DELEGATE_HPP
