@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -70,7 +70,7 @@ class MAPNIK_DECL font_face : util::noncopyable
     bool init_color_font();
 
     FT_Face face_;
-    const bool color_font_;
+    bool const color_font_;
 };
 using face_ptr = std::shared_ptr<font_face>;
 
