@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -159,7 +159,7 @@ struct do_xml_attribute_cast<double>
 // specialization for mapnik::enumeration<...>
 template<typename ENUM,
          char const* (*F_TO_STRING)(ENUM),
-         ENUM (*F_FROM_STRING)(const char*),
+         ENUM (*F_FROM_STRING)(char const*),
          std::map<ENUM, std::string> (*F_LOOKUP)()>
 struct do_xml_attribute_cast<mapnik::enumeration<ENUM, F_TO_STRING, F_FROM_STRING, F_LOOKUP>>
 {
