@@ -40,7 +40,7 @@ using mapnik::datasource;
 using mapnik::parameters;
 
 DATASOURCE_PLUGIN_IMPL(topojson_datasource_plugin, topojson_datasource);
-DATASOURCE_PLUGIN_EXPORT(topojson_datasource_plugin);
+DATASOURCE_PLUGIN_EXPORT(topojson);
 DATASOURCE_PLUGIN_EMPTY_AFTER_LOAD(topojson_datasource_plugin);
 DATASOURCE_PLUGIN_EMPTY_BEFORE_UNLOAD(topojson_datasource_plugin);
 
