@@ -38,13 +38,13 @@
 namespace mapnik {
 
 projection::projection(std::string const& params, bool defer_proj_init)
-    : params_(params)
-    , defer_proj_init_(defer_proj_init)
-    , is_geographic_(false)
-    , proj_(nullptr)
-    , proj_ctx_(nullptr)
+    : params_(params),
+      defer_proj_init_(defer_proj_init),
+      is_geographic_(false),
+      proj_(nullptr),
+      proj_ctx_(nullptr)
 {
-    const auto is_known = is_known_geographic(params_);
+    auto const is_known = is_known_geographic(params_);
     if (is_known.has_value())
     {
         is_geographic_ = *is_known;
@@ -63,11 +63,11 @@ projection::projection(std::string const& params, bool defer_proj_init)
 }
 
 projection::projection(projection const& rhs)
-    : params_(rhs.params_)
-    , defer_proj_init_(rhs.defer_proj_init_)
-    , is_geographic_(rhs.is_geographic_)
-    , proj_(nullptr)
-    , proj_ctx_(nullptr)
+    : params_(rhs.params_),
+      defer_proj_init_(rhs.defer_proj_init_),
+      is_geographic_(rhs.is_geographic_),
+      proj_(nullptr),
+      proj_ctx_(nullptr)
 {
     if (!defer_proj_init_)
         init_proj();
@@ -84,12 +84,12 @@ projection& projection::operator=(projection const& rhs)
     return *this;
 }
 
-bool projection::operator==(const projection& other) const
+bool projection::operator==(projection const& other) const
 {
     return (params_ == other.params_);
 }
 
-bool projection::operator!=(const projection& other) const
+bool projection::operator!=(projection const& other) const
 {
     return !(*this == other);
 }
